package com.hongyegroup.cpt_newsfeed.ui.fragment

import android.os.Bundle
import android.view.View
import androidx.viewpager2.widget.ViewPager2
import com.guadou.cs_cptservices.base.fragment.YYBaseVDBFragment
import com.guadou.cs_cptservices.interfaces.IFragmentRefresh
import com.guadou.lib_baselib.bean.DataBindingConfig
import com.guadou.lib_baselib.engine.toast
import com.guadou.lib_baselib.ext.bindFragment
import com.guadou.lib_baselib.utils.CommUtils
import com.hongyegroup.cpt_newsfeed.BR
import com.hongyegroup.cpt_newsfeed.R
import com.hongyegroup.cpt_newsfeed.databinding.FragmentNewsfeedMainBinding
import com.hongyegroup.cpt_newsfeed.mvvm.NewsFeedMainViewModel
import com.hongyegroup.cpt_newsfeed.ui.activity.NewsFeedPostActivity

/**
 * 首页动态广场的页面
 * Tab + ViewPager
 */
class NewsFeedMainFragment : YYBaseVDBFragment<NewsFeedMainViewModel, FragmentNewsfeedMainBinding>(), IFragmentRefresh {

    private var mCurPage = 1
    private lateinit var mNewsFeedFollowingFragment: NewsFeedListFragment
    private lateinit var mNewsFeedMonentsFragment: NewsFeedListFragment
    private lateinit var mNewsFeedProfileFragment: NewsFeedProfileFragment

    override fun getDataBindingConfig(): DataBindingConfig {
        return DataBindingConfig(R.layout.fragment_newsfeed_main, BR.viewModel, mViewModel)
            .addBindingParams(BR.click, ClickProxy())
    }

    override fun startObserve() {
    }

    override fun init(savedInstanceState: Bundle?) {
        setStatusBarBlackText()

        initAdapter()
    }

    private fun initAdapter() {
        mNewsFeedFollowingFragment = NewsFeedListFragment(1)
        mNewsFeedMonentsFragment = NewsFeedListFragment(0)
        mNewsFeedProfileFragment = NewsFeedProfileFragment("8558", true)

        mViewModel.mFragments.add(mNewsFeedMonentsFragment)
        mViewModel.mFragments.add(mNewsFeedFollowingFragment)
        mViewModel.mFragments.add(mNewsFeedProfileFragment)

        mBinding.viewPager.bindFragment(childFragmentManager, this.lifecycle, mViewModel.mFragments)

        mBinding.viewPager.registerOnPageChangeCallback(object : ViewPager2.OnPageChangeCallback() {
            override fun onPageSelected(position: Int) {
                mCurPage = position
                setIndicator(position)
            }
        })

        mBinding.viewPager.currentItem = 1
    }

    //点击顶部选择切换ViewPager的效果
    private fun setCurrentPage(index: Int) {
        mBinding.viewPager.currentItem = index
        setIndicator(index)
    }

    //滑动ViewPager切换顶部选择的效果
    private fun setIndicator(position: Int) {
        mCurPage = position
        when (position) {
            0 -> {
                mBinding.textFlowing.setTextColor(CommUtils.getColor(R.color.app_blue))
                mBinding.viewFollowingLine.visibility = View.VISIBLE
                mBinding.textMoments.setTextColor(CommUtils.getColor(R.color.gray_88))
                mBinding.viewMonentLine.visibility = View.GONE
                mBinding.textProfile.setTextColor(CommUtils.getColor(R.color.gray_88))
                mBinding.viewProfile.visibility = View.GONE
            }
            1 -> {
                mBinding.textFlowing.setTextColor(CommUtils.getColor(R.color.gray_88))
                mBinding.viewFollowingLine.visibility = View.GONE
                mBinding.textMoments.setTextColor(CommUtils.getColor(R.color.app_blue))
                mBinding.viewMonentLine.visibility = View.VISIBLE
                mBinding.textProfile.setTextColor(CommUtils.getColor(R.color.gray_88))
                mBinding.viewProfile.visibility = View.GONE
            }
            else -> {
                mBinding.textFlowing.setTextColor(CommUtils.getColor(R.color.gray_88))
                mBinding.viewFollowingLine.visibility = View.GONE
                mBinding.textMoments.setTextColor(CommUtils.getColor(R.color.gray_88))
                mBinding.viewMonentLine.visibility = View.GONE
                mBinding.textProfile.setTextColor(CommUtils.getColor(R.color.app_blue))
                mBinding.viewProfile.visibility = View.VISIBLE
            }
        }
    }

    override fun scrollTopRefresh() {
        when (mCurPage) {
            0 -> mNewsFeedMonentsFragment.scrollTopRefresh()
            1 -> mNewsFeedFollowingFragment.scrollTopRefresh()
            else -> mNewsFeedProfileFragment.scrollTopRefresh()
        }
    }

    /**
     * DataBinding事件处理
     */
    inner class ClickProxy {

        //返回页面
        fun pageBack() {
            mActivity.finish()
        }

        //去搜索页面
        fun gotoSearchPage() {
          toast("去搜索页面")
        }

        //切换已关注的
        fun switchFollowing() {
            if (mCurPage == 0) {
                mNewsFeedFollowingFragment.scrollTopRefresh()
            } else {
                setCurrentPage(0)
            }
        }

        //切换到朋友圈
        fun switchMoments() {
            if (mCurPage == 1) {
                mNewsFeedMonentsFragment.scrollTopRefresh()
            } else {
                setCurrentPage(1)
            }
        }

        //切换我的发布
        fun switchPulished() {
            if (mCurPage == 2) {
                mNewsFeedProfileFragment.scrollTopRefresh()
            } else {
                setCurrentPage(2)
            }
        }

        //去发布页面
        fun gotoPostPage() {
            NewsFeedPostActivity.startInstance()
        }

    }

}